@@ -109,8 +109,8 @@ setClass("calib",
 				inver.up="numOrNULL",
 				wald.low="numOrNULL",
 				wald.up="numOrNULL",
-				waldl.low="numOrNULL",
-				waldl.up="numOrNULL",
+#				waldl.low="numOrNULL",
+#				waldl.up="numOrNULL",
 				avg.response="numeric",
 				dilution="numeric",
 				oor="character",
